#!/bin/bash
# (c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

set -ex

# Install freezer devstack integration
#export DEVSTACK_LOCAL_CONFIG="enable_plugin freezer-api https://git.openstack.org/openstack/freezer-api"

# Invoke default behavior.


unset DEVSTACK_GATE_TEMPEST
unset DEVSTACK_GATE_TEMPEST_ALL_PLUGINS
unset DEVSTACK_GATE_TEMPEST_REGEX
export DEVSTACK_GATE_TEMPEST_REGEX="freezer_api_tempest_plugin"

$BASE/new/devstack-gate/devstack-vm-gate.sh

cd $BASE/new/freezer-web-ui

# tox -r -v
